@@ -16,8 +16,7 @@ lay = """
          date        time
 #         datetime    datetime_tz
          datetime    
-         time        time_tz
-         interval
+         time_tz     interval
          }
 
 {|.numbers
@@ -36,8 +35,8 @@ for name in ('text','date', 'numbers', 'boolean'):
 t.reload()
 
 
-t = SqlTable(model.AllTypes, dbproxy=db )
-t.reload()
+t1 = SqlTable(model.AllTypes, dbproxy=db )
+t1.reload()
 
 
 
