@@ -447,7 +447,7 @@ class VarcharColumn(GenericColumn):
         if self.field.length:
             try:
                 ## if field has less then 4 chars, position it in the middle
-                if int(length) <= 4:
+                if int(self.field.length) <= 4:
                     cell.set_property('xalign', 0.5)
             except:
                 pass
@@ -702,6 +702,32 @@ class ImageColumn(GenericColumn):
     PROPERTY = 'pixbuf'
     editable = False
 
+    def __init__(self, master, field_name, title, field=None):
+
+        GenericColumn.__init__(self, master, field_name, title, field=None)
+        try:
+            master.treeview.props.has_tooltip = True
+            master.treeview.connect('query-tooltip', self.return_image_path, )
+        except AttributeError:
+            pass
+
+    def return_image_path(self, treeview, x, y, keyboard_mode, tooltip):
+        "Set a tooltip with the file/image name"
+        try:
+            path, column, x_in_cell, y_in_cell = treeview.get_path_at_pos(x,y)
+        except TypeError:
+            return
+        idx = path[0]
+        if not idx: #header
+            return
+        path = tuple([idx-1])
+        model = treeview.get_model()
+        obj = model.get_value(model.get_iter(path), 0)
+        file_path = getattr(obj, self.field_name)
+        if file_path and (column.get_data('field_name') == self.field_name):
+            tooltip.set_text(file_path)
+            return True
+
     def set_editable(self, editable):
         pass
     def cell_set_property(self, cell):
@@ -742,6 +768,12 @@ class ImageColumn(GenericColumn):
         if isinstance(obj, self.master.mapper.class_):
             cell.set_property('visible', True)
             if value:
+                if not self.field.exists(value):
+                    cell.set_property('pixbuf', None)
+                    cell.set_property('stock-id', 'gtk-missing-image')
+                    cell.set_data('thumbnail_path', None)
+                    return
+
                 if self.field.is_image(value):
                     thumbnail_path = value and self.field.get_thumbnail(value, complete_path=True) or None
                     if thumbnail_path:
@@ -1004,7 +1036,8 @@ class ColumnMenuProxy(object):
             self.master.modelproxy.order_by(None)
             order_by = field_name
             if self.master.is_fkey(field_name):
-                ftable = getattr(self.master.mapper.c, field_name).foreign_keys[0].column.table
+                ftable = getattr(self.master.mapper.c, field_name
+                                 ).foreign_keys.copy().pop().column.table
                 fdescr = get_description(ftable, attr='description')
                 order_by = "%s__%s" % (field_name, fdescr)
 
@@ -1325,6 +1358,15 @@ class View(object):
         action_upload_image = self.ui_manager.get_action('/TreePopup/UploadImage')
         if obj and field_name and self.master.is_image(field_name):
             action_upload_image.set_visible(True)
+
+            # don't show missing images...
+            action_show_image = self.ui_manager.get_action('/TreePopup/ShowFile')
+            filename = getattr(obj, field_name)
+            if obj and filename and self.master.gui_fields[field_name].exists(filename):
+                action_show_image.set_sensitive(True)
+            else:
+                action_show_image.set_sensitive(False)
+
         else:
             action_upload_image.set_visible(False)
             
