@@ -51,7 +51,7 @@ class SqlTable(sqlwidget.SqlWidget):
     & similar).
 
     A SqlTable can have different :ref:`views <views>` of the same data
-    represented in different TreeVies.
+    represented in different TreeViews.
 
     A SqlTable can be viewed alone or as part of a composite widget, that is
     normally a mask with :ref:`relationships`: be sure to understand this
@@ -256,8 +256,15 @@ class SqlTable(sqlwidget.SqlWidget):
     def _get_edited_path(self):
         "return the curretly edited path as a tuple"
 
-        return self.edited_row_model_path and \
-               tuple(int(x) for x in self.edited_row_model_path.split(':'))
+        try:
+            return self.edited_row_model_path and \
+                   tuple(int(x) for x in self.edited_row_model_path.split(':'))
+        except AttributeError:
+            ## edited_row_model_path may also be already a tuple...
+            if isinstance(self.edited_row_model_path, tuple):
+                return self.edited_row_model_path
+                   
+            
 
     edited_path = property(_get_edited_path)
 
@@ -935,20 +942,22 @@ class SqlTable(sqlwidget.SqlWidget):
         self.emit('record-new')
         return path, self.last_new_obj
 
-    def record_add(self, record):
+    def record_add(self, obj, parent_path=None):
         """
         Add a record to the SqlTable
+
+        :param obj: the object to be added
+        :param parent_path: a possible path of the parent
+        :returns: the new path
         """
-#         try:
-#             self.modelproxy.modelstore.append([record])
-#         except Exception:
-#             self.modelproxy.modelstore.append(None, [record])
-        sqlwidget.SqlWidget.record_add(self, record)
-        path, obj = self.record_new(obj=record, start=False)
+        
+        sqlwidget.SqlWidget.record_add(self, obj)
+        path, obj = self.record_new(obj=obj, start=False, parent=parent_path)
         self.edited_row_model_path  =  path
         self.select_path(path)
         self.record_save()
         self.totals.compute()
+        return path
         
     def unsaved_changes_exist(self, skip_check=False, skip_new=False):
         """collect possible changes and test if save is needed
@@ -978,21 +987,29 @@ class SqlTable(sqlwidget.SqlWidget):
             self.sb(_('No record selected'))
             return True
 
+        sel = self.treeview.get_selection()
+        model, paths = sel.get_selected_rows()
+
         if interactive:
             text = _("Delete this record?\n(%s)") % self.current
+            iter = model.get_iter(paths[0])
+            if model.iter_has_child(iter):
+                text += "\n" + _("All children will be deleted as well") 
             response = self.dialog(type='ok-cancel', text=text)
             if response == gtk.RESPONSE_CANCEL:
                 return
 
         self.deleting_row = True
 
-        sel = self.treeview.get_selection()
-        model, paths = sel.get_selected_rows()
-
         def do_del(model, path, iter):
             """
             potentially can delete a selection of many rows
             """
+            ## Recursively delete all children, if any
+            if model.iter_has_child(iter):
+                for i in range(model.iter_n_children(iter), 0, -1): # backward
+                    it = model.iter_nth_child(iter, i-1)
+                    do_del(model, model.get_path(it), it)
 
             obj = model[path][0]
             deleted = True
@@ -1299,13 +1316,19 @@ class SqlTable(sqlwidget.SqlWidget):
         
         self.select_path(obj=obj)
         mask.set_records([obj])
+        ## update value in the table, when updated in mask
         def update_table_treeview(mask, table):
             # emitting a 'row-changed', forces the update of the treeview 
             model = self.modelproxy.modelstore
             path = table.get_selected_path()
             if path: # seems selection sometimes is lost
                 model.emit('row-changed', path, model.get_iter(path))
-        mask.connect('record-saved', update_table_treeview, self)
+        record_save_id = mask.connect('record-saved', update_table_treeview, self)
+
+        def disconnect_table(table, id):
+            mask.disconnect(id)
+
+        self.connect('delete-event', disconnect_table, record_save_id)
 
         ## signals to keep selection in sync 
         def follow_selection(table, obj, mask):
@@ -1429,8 +1452,17 @@ class SqlTable(sqlwidget.SqlWidget):
         from sqlkit.layout import image_widget
         
         field_name = field_name or self._field_name
-        self.initialize_record_editing(self._clicked_path, force=True, obj=self._clicked_obj)
+
+        self.select_path(self._clicked_path)
+        self.initialize_record_editing(self._clicked_path, force=True,
+                                       obj=self.get_obj_at_path(self._clicked_path))
+        # if you don't select it, the table mix up values of different rows, probably
+        # _clicked_path gets used in wrong ways...
         filename = self.gui_fields[field_name].get_value(complete_path=True)
+        if not os.path.exists(filename):
+            self.message(text=_("File '%s' is not present in the filesystem" % filename),
+                                type='error')
+            return
         if not self.gui_fields[field_name].is_image(filename):
             open_file(filename)
             return
